@@ -18,8 +18,8 @@
 #' @export
 #' @examples
 #' # dfm_compress examples
-#' dfmat <- rbind(dfm(c("b A A", "C C a b B"), tolower = FALSE),
-#'              dfm("A C C C C C", tolower = FALSE))
+#' dfmat <- rbind(dfm(tokens(c("b A A", "C C a b B")), tolower = FALSE),
+#'                dfm(tokens("A C C C C C"), tolower = FALSE))
 #' colnames(dfmat) <- char_tolower(featnames(dfmat))
 #' dfmat
 #' dfm_compress(dfmat, margin = "documents")
@@ -27,7 +27,7 @@
 #' dfm_compress(dfmat)
 #'
 #' # no effect if no compression needed
-#' dfmatsubset <- dfm(data_corpus_inaugural[1:5])
+#' dfmatsubset <- dfm(tokens(data_corpus_inaugural[1:5]))
 #' dim(dfmatsubset)
 #' dim(dfm_compress(dfmatsubset))
 #'
@@ -38,19 +38,28 @@ dfm_compress <- function(x, margin = c("both", "documents", "features")) {
 #' @export
 dfm_compress.default <- function(x,
                                  margin = c("both", "documents", "features")) {
-    stop(friendly_class_undefined_message(class(x), "dfm_compress"))
+    check_class(class(x), "dfm_compress")
 }
 
 #' @export
 dfm_compress.dfm <- function(x, margin = c("both", "documents", "features")) {
-
+    
     x <- as.dfm(x)
-    if (!nfeat(x) || !ndoc(x)) return(x)
     margin <- match.arg(margin)
+    
+    if (!nfeat(x) || !ndoc(x)) return(x)
+    
+    attrs <- attributes(x)
     documents <- features <- NULL
     if (margin %in% c("both", "documents"))
         documents <- factor(docnames(x), levels = unique(docnames(x)))
     if (margin %in% c("both", "features"))
         features <- factor(featnames(x), levels = unique(featnames(x)))
-    group_dfm(x, documents, features)
+    
+    x <- group_matrix(x, documents, features)
+    build_dfm(x, colnames(x),
+              unit = "documents",
+              docvars = group_docvars(attrs[["docvars"]], documents),
+              meta = attrs[["meta"]]
+    )
 }
