@@ -110,11 +110,9 @@ dfm_weight.dfm <- function(x,
         weights <- weights[!ignore]
         weight[match(names(weights), names(weight))] <- weights
 
-        weight <- Diagonal(x = weight)
-        colnames(weight) <- colnames(x)
-        result <- x %*% weight
-        dimnames(result) <- dimnames(x)
-        return(result)
+        m <- dimnames(x)
+        x <- matrix2dfm(x %*% Diagonal(x = weight))
+        dimnames(x) <- m
 
     } else {
         ### for scheme weights
@@ -163,8 +161,8 @@ dfm_weight.dfm <- function(x,
             field_object(attrs, "weight_tf")$base <- base
         }
         field_object(attrs, "weight_tf")$scheme <- scheme
-        rebuild_dfm(x, attrs)
     }
+    rebuild_dfm(x, attrs)
 }
 
 
