@@ -115,15 +115,21 @@ fcm.default <- function(x, ...) {
 #' @noRd
 #' @export
 fcm.character <- function(x, ...) {
-    .Deprecated(msg = "'fcm.character()' is deprecated. Use 'tokens()' or 'dfm()' first.")
-    fcm(corpus(x), ...)
+    lifecycle::deprecate_stop(
+        when = "3.0", 
+        what = "fcm.character()",
+        details = 'Please apply `tokens()` to the object first.'
+    )
 }
 
 #' @noRd
 #' @export
 fcm.corpus <- function(x, ...) {
-    .Deprecated(msg = "'fcm.corpus()' is deprecated. Use 'tokens()' or 'dfm()' first.")
-    fcm(tokens(x), ...)
+    lifecycle::deprecate_stop(
+        when = "3.0", 
+        what = "fcm.corpus()",
+        details = 'Please apply `tokens()` to the object first.'
+    )
 }
 
 #' @noRd
@@ -190,14 +196,13 @@ fcm.dfm <- function(x, context = c("document", "window"),
 #' @noRd
 #' @import Matrix
 #' @export
-fcm.tokens <- function(x, context = c("document", "window"),
+fcm.tokens_xptr <- function(x, context = c("document", "window"),
                        count = c("frequency", "boolean", "weighted"),
                        window = 5L,
                        weights = NULL,
                        ordered = FALSE,
                        tri = TRUE, ...) {
 
-    x <- as.tokens(x)
     context <- match.arg(context)
     count <- match.arg(count)
     window <- check_integer(window, min = 1)
@@ -221,9 +226,10 @@ fcm.tokens <- function(x, context = c("document", "window"),
         } else {
             weights <- rep(1, window)
         }
-        type <- types(x)
+        type <- get_types(x)
         boolean <- count == "boolean"
-        temp <- qatd_cpp_fcm(x, length(type), weights, boolean, ordered)
+        temp <- cpp_fcm(x, length(type), weights, boolean, ordered,
+                        get_threads())
         temp <- as(temp, "CsparseMatrix")
         if (!ordered) {
             if (tri) {
@@ -242,6 +248,11 @@ fcm.tokens <- function(x, context = c("document", "window"),
     return(result)
 }
 
+#' @export
+fcm.tokens <- function(x, ...) {
+    fcm(as.tokens_xptr(x), ...)
+}
+
 #' @noRd
 #' @rdname as.fcm
 #' @export
