@@ -9,9 +9,9 @@
     quanteda_options(initialize = TRUE)
     
     # threads message
-    if (qatd_cpp_tbb_enabled()) {
+    if (cpp_tbb_enabled()) {
         packageStartupMessage("Parallel computing: ", quanteda_options("threads"), " of ", 
-                              RcppParallel::defaultNumThreads(), " threads used.")
+                              cpp_get_max_thread(), " threads used.")
     } else {
         packageStartupMessage("Parallel computing: disabled") 
     }
