@@ -1,14 +1,15 @@
-test_that("as.dictionary works for data.frame", {
+test_that("as.dictionary works", {
     df <- data.frame(
         word = letters[1:6],
         sentiment = c("neg", "neg", "neutral", "neutral", "pos", "pos"),
         lexicon = rep("madeup", 6),
         stringsAsFactors = FALSE
     )
+    lis <- list(neg = c("a", "b"), 
+                neutral = c("c", "d"), 
+                pos = c("e", "f"))
     expect_equal(
-        dictionary(list(neg = c("a", "b"), 
-                        neutral = c("c", "d"), 
-                        pos = c("e", "f"))),
+        dictionary(lis),
         as.dictionary(df, format = "tidytext")
     )
     df <- data.frame(
@@ -18,10 +19,13 @@ test_that("as.dictionary works for data.frame", {
         stringsAsFactors = TRUE
     )
     expect_equal(
-        dictionary(list(neg = c("a", "b"), 
-                        neutral = c("c", "d"), pos = c("e", "f"))),
+        dictionary(lis),
         as.dictionary(df, format = "tidytext")
     )
+    expect_equal(
+        dictionary(lis),
+        as.dictionary(lis)
+    )
 })
 
 test_that("as.dictionary warnings and errors", {
@@ -87,3 +91,24 @@ test_that("options for tidytext only currently supported", {
         "'arg' should be (one of )*[“\"]tidytext[”\"]"
     )
 })
+
+test_that("as.dictionary.list works", {
+    l <- list(Word = c("A", "B"),
+              Sentiment = c("Pos Word", "Neg_Word"))
+    expect_identical(
+        dictionary(l),
+        as.dictionary(l)
+    )
+    expect_identical(
+        dictionary(l, tolower = FALSE),
+        as.dictionary(l, tolower = FALSE)
+    )
+    expect_identical(
+        meta(as.dictionary(l, separator = " "), type = "all")$object$separator,
+        " "
+    )
+    expect_identical(
+        meta(as.dictionary(l, separator = "_"), type = "all")$object$separator,
+        "_"
+    )
+})
